OC.L10N.register(
    "forms",
    {
    "Copy" : "Copiar",
    "Shared with you" : "Compartido con usted",
    "Select groups" : "Seleccionar grupos",
    "Cancel" : "Cancel",
    "Required" : "Requerido",
    "Delete" : "Borrar",
    "never" : "nunca",
    "Set expiration date" : "Establecer fecha de expiración",
    "Group" : "Grupo",
    "Permissions" : "Permisos",
    "Share link" : "Compartir liga",
    "Copy to clipboard" : "Copiar al portapapeles",
    "Edit" : "Editar",
    "View mode" : "Modo de visualización",
    "Share" : "Compartir",
    "Description" : "Descripción",
    "Summary" : "Resumen",
    "Search" : "Buscar",
    "Sharing" : "Compartiendo",
    "Settings" : "Configuraciones ",
    "Abort" : "Abortar",
    "Submit" : "Enviar",
    "Clear" : "Limpiar",
    "File" : "Archivo",
    "Date" : "Fecha",
    "Time" : "Hora",
    "Color" : "Color",
    "Text" : "Texto",
    "Phone number" : "Número de teléfono",
    "Uploading …" : "Cargando..."
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
